#ifndef NT2_INCLUDE_FUNCTIONS_ACOT_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACOT_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/acot.hpp>

#endif
